A map that creates a random handle on insertion to use when retrieving.
Structs
- Handle
- The handle to a
RandMapitem is a typedu64. - Iter
- The type returned by
RandMap::iter(). - IterMut
- The type returned by
RandMap::iter_mut(). - RandMap
- A map that creates a random handle on insertion to use when retrieving.